Introduction - Test/demo document for testing the mkdocs extension tagtomarkdown

## Test tagtomarkdown tags in markdown file

Just some text, until further.
and a home made line break and more text.

### Try tables

No | Text | Remarks
--- | --- | ---
1 | Here is the first row. You can write as many lines here as you want. |
2 | And the second | And a bit of a comment here.
3 | and that's it. |

Table 1: Some caption text for the table

### Try ordered lists

1. Number one and with quite some text, so that we can show that there can be more input lines here. But note that when there is a keyword after the >li, there should be no more text in that line
2. Next item.
3. Note no keyword (*incr) here.

## Test references to table row numbers and ordered list numbers

Here, we can refer symbolically row 2 in the table above and the ordered list item 2.

## A few other services

Last update: 2019-03-06 16:37:31.